pub enum McpSurfaceSource {
NativeCard,
SkillCard,
}Expand description
Origin record that a projected McpSurfaceCard was derived from.
Variants
NativeCard
The row was projected from a native browse McpNativeCard.
SkillCard
The row was projected from an agent skill card.
Implementations