pub fn project_native_surface(
native_cards: &[McpNativeCard],
profile: &McpProfile,
) -> Result<Vec<McpSurfaceCard>>Expand description
Projects native cards into surface rows filtered by profile.
pub fn project_native_surface(
native_cards: &[McpNativeCard],
profile: &McpProfile,
) -> Result<Vec<McpSurfaceCard>>Projects native cards into surface rows filtered by profile.