McpExportFacet

Struct McpExportFacet 

pub struct McpExportFacet {
    pub role: McpSurfaceRole,
    pub name: Option<String>,
    pub symbol: Option<Symbol>,
    pub uri: Option<String>,
    pub description: Option<String>,
    pub input_shape: Option<ShapeRef>,
    pub output_shape: Option<ShapeRef>,
    pub annotations: Vec<McpAnnotation>,
    pub capabilities: Vec<CapabilityName>,
    pub stream_policy: McpStreamPolicy,
}
Describes how a native card subject is exported onto the MCP surface.

Fields

role: McpSurfaceRole

MCP role of the exported row.

name: Option<String>

Explicit MCP name; defaults to the subject when absent.

symbol: Option<Symbol>

Backing symbol; defaults to the card subject when absent.

uri: Option<String>

Resource URI override.

description: Option<String>

Description override.

input_shape: Option<ShapeRef>

Input shape override.

output_shape: Option<ShapeRef>

Output shape override.

annotations: Vec<McpAnnotation>

Annotations attached to the exported row.

capabilities: Vec<CapabilityName>

Extra capabilities required by the exported row.

stream_policy: McpStreamPolicy

Streaming behavior advertised by the exported row.

Implementations

Source

impl McpExportFacet

pub fn tool() -> Self

Builds a tool export facet.

pub fn resource() -> Self

Builds a resource export facet.

pub fn prompt() -> Self

Builds a prompt export facet.

pub fn model() -> Self

Builds a model export facet.

pub fn new(role: McpSurfaceRole) -> Self

Builds an export facet for role with all overrides unset.

pub fn with_name(self, name: impl Into<String>) -> Self

Returns the facet with an explicit MCP name.

pub fn with_symbol(self, symbol: Symbol) -> Self

Returns the facet with an explicit backing symbol.

pub fn with_uri(self, uri: impl Into<String>) -> Self

Returns the facet with an explicit resource uri.

pub fn with_description(self, description: impl Into<String>) -> Self

Returns the facet with an explicit description.

pub fn with_annotation(self, annotation: McpAnnotation) -> Self

Returns the facet with annotation appended.

pub fn with_capability(self, capability: CapabilityName) -> Self

Returns the facet with capability added to its requirements.

pub fn with_stream_policy(self, policy: McpStreamPolicy) -> Self

Returns the facet with its stream policy set.